@@ -21,7 +21,6 @@ import (
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/source_metadatapb"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/sourcespb"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/sources"
-	"github.com/trufflesecurity/trufflehog/v3/pkg/sources/git"
 )
 
 func TestSource_Token(t *testing.T) {
@@ -42,7 +41,8 @@ func TestSource_Token(t *testing.T) {
 	githubInstallationIDNew := secret.MustGetField("GITHUB_INSTALLATION_ID_NEW")
 	githubAppIDNew := secret.MustGetField("GITHUB_APP_ID_NEW")
 
-	conn := &sourcespb.GitHub{
+	src := &sourcespb.GitHub{
+		Endpoint: "https://api.github.com",
 		Credential: &sourcespb.GitHub_GithubApp{
 			GithubApp: &credentialspb.GitHubApp{
 				PrivateKey:     githubPrivateKeyNew,
@@ -51,32 +51,24 @@ func TestSource_Token(t *testing.T) {
 			},
 		},
 	}
+	conn, err := anypb.New(src)
+	if err != nil {
+		panic(err)
+	}
 
 	s := Source{
-		conn:          conn,
-		httpClient:    common.SaneHttpClient(),
+		conn:          src,
 		log:           logr.Discard(),
 		memberCache:   map[string]struct{}{},
 		repoInfoCache: newRepoInfoCache(),
 	}
+	s.Init(ctx, "github integration test source", 0, 0, false, conn, 1)
 	s.filteredRepoCache = s.newFilteredRepoCache(memory.New[string](), nil, nil)
 
-	installationClient, err := s.enumerateWithApp(ctx, "https://api.github.com", conn.GetGithubApp())
+	err = s.enumerateWithApp(ctx, s.connector.(*appConnector).InstallationClient())
 	assert.NoError(t, err)
 
-	user, token, err := s.userAndToken(ctx, installationClient)
-	assert.NotEmpty(t, token)
-	assert.NoError(t, err)
-
-	// user provided
-	_, _, err = git.CloneRepoUsingToken(ctx, token, "https://github.com/truffle-test-integration-org/another-test-repo.git", user)
-	assert.NoError(t, err)
-
-	// no user provided
-	_, _, err = git.CloneRepoUsingToken(ctx, token, "https://github.com/truffle-test-integration-org/another-test-repo.git", "")
-	assert.Error(t, err)
-
-	_, _, err = s.cloneRepo(ctx, "https://github.com/truffle-test-integration-org/another-test-repo.git", installationClient)
+	_, _, err = s.cloneRepo(ctx, "https://github.com/truffle-test-integration-org/another-test-repo.git")
 	assert.NoError(t, err)
 }
 
@@ -316,16 +308,6 @@ func TestSource_Scan(t *testing.T) {
 	githubInstallationIDNew := secret.MustGetField("GITHUB_INSTALLATION_ID_NEW")
 	githubAppIDNew := secret.MustGetField("GITHUB_APP_ID_NEW")
 
-	// OLD app for breaking app change tests
-	// githubPrivateKeyB64 := secret.MustGetField("GITHUB_PRIVATE_KEY")
-	// githubPrivateKeyBytes, err := base64.StdEncoding.DecodeString(githubPrivateKeyB64)
-	// if err != nil {
-	// 	t.Fatal(err)
-	// }
-	// githubPrivateKey := string(githubPrivateKeyBytes)
-	// githubInstallationID := secret.MustGetField("GITHUB_INSTALLATION_ID")
-	// githubAppID := secret.MustGetField("GITHUB_APP_ID")
-
 	type init struct {
 		name       string
 		verify     bool
@@ -403,117 +385,78 @@ func TestSource_Scan(t *testing.T) {
 			wantChunk: nil,
 			wantErr:   false,
 			minRepo:   1,
+			minOrg:    1,
+		},
+		{
+			name: "token authenticated, username in org",
+			init: init{
+				name: "test source",
+				connection: &sourcespb.GitHub{
+					Organizations: []string{"truffle-sandbox"},
+					Credential: &sourcespb.GitHub_Token{
+						Token: githubToken,
+					},
+				},
+			},
+			wantChunk: nil,
+			wantErr:   false,
+			minRepo:   2,
+			minOrg:    1,
+		},
+		{
+			name: "token authenticated, no org or user (enum)",
+			// This configuration currently will only find gists from the user. No repos or orgs will be scanned.
+			init: init{
+				name: "test source",
+				connection: &sourcespb.GitHub{
+					Credential: &sourcespb.GitHub_Token{
+						Token: githubToken,
+					},
+				},
+			},
+			wantChunk: nil,
+			wantErr:   false,
+			minRepo:   2,
 			minOrg:    0,
 		},
-		// {
-		// 	name: "token authenticated, username in org",
-		// 	init: init{
-		// 		name: "test source",
-		// 		connection: &sourcespb.GitHub{
-		// 			Organizations: []string{"truffle-sandbox"},
-		// 			Credential: &sourcespb.GitHub_Token{
-		// 				Token: githubToken,
-		// 			},
-		// 		},
-		// 	},
-		// 	wantChunk: nil,
-		// 	wantErr:   false,
-		// 	minRepo:   0, // I think enumerating users with the org API does not work for newer users! Or maybe just newer users with a `-` in their name?
-		// 	// See also: https://github.com/trufflesecurity/trufflehog/issues/874
-		// 	minOrg: 0,
-		// },
-		// {
-		// 	name: "token authenticated, org in repo",
-		// 	// I do not think that this is a supported case, but adding the test to specify there is no requirement.
-		// 	init: init{
-		// 		name: "test source",
-		// 		connection: &sourcespb.GitHub{
-		// 			Repositories: []string{"truffle-test-integration-org"},
-		// 			Credential: &sourcespb.GitHub_Token{
-		// 				Token: githubToken,
-		// 			},
-		// 		},
-		// 	},
-		// 	wantChunk: nil,
-		// 	wantErr:   false,
-		// 	minRepo:   0,
-		// 	minOrg:    0,
-		// },
-		/*
-			{
-				name: "token authenticated, no org or user (enum)",
-				// This configuration currently will only find gists from the user. No repos or orgs will be scanned.
-				init: init{
-					name: "test source",
-					connection: &sourcespb.GitHub{
-						Credential: &sourcespb.GitHub_Token{
-							Token: githubToken,
+		{
+			name: "unauthenticated, single org",
+			init: init{
+				name: "test source",
+				connection: &sourcespb.GitHub{
+					Organizations: []string{"trufflesecurity"},
+					Credential:    &sourcespb.GitHub_Unauthenticated{},
+					IncludeForks:  true,
+				},
+			},
+			wantChunk: nil,
+			wantErr:   false,
+			minRepo:   40,
+			minOrg:    1,
+		},
+		{
+			name: "unauthenticated, single repo",
+			init: init{
+				name: "test source",
+				connection: &sourcespb.GitHub{
+					Repositories: []string{"https://github.com/trufflesecurity/driftwood.git"},
+					Credential:   &sourcespb.GitHub_Unauthenticated{},
+				},
+			},
+			wantChunk: &sources.Chunk{
+				SourceType: sourcespb.SourceType_SOURCE_TYPE_GITHUB,
+				SourceName: "test source",
+				SourceMetadata: &source_metadatapb.MetaData{
+					Data: &source_metadatapb.MetaData_Github{
+						Github: &source_metadatapb.Github{
+							Repository: "https://github.com/trufflesecurity/driftwood.git",
 						},
 					},
 				},
-				wantChunk: nil,
-				wantErr:   false,
-				minRepo:   0,
-				minOrg:    0,
+				Verify: false,
 			},
-			{
-				name: "app authenticated (old), no repo or org (enum)",
-				init: init{
-					name: "test source",
-					connection: &sourcespb.GitHub{
-						ScanUsers: false,
-						Credential: &sourcespb.GitHub_GithubApp{
-							GithubApp: &credentialspb.GitHubApp{
-								PrivateKey:     githubPrivateKey,
-								InstallationId: githubInstallationID,
-								AppId:          githubAppID,
-							},
-						},
-					},
-				},
-				wantChunk: nil,
-				wantErr:   false,
-				minRepo:   3,
-				minOrg:    0,
-			},
-		*/
-		// {
-		// 	name: "unauthenticated, single org",
-		// 	init: init{
-		// 		name: "test source",
-		// 		connection: &sourcespb.GitHub{
-		// 			Organizations: []string{"trufflesecurity"},
-		// 			Credential:    &sourcespb.GitHub_Unauthenticated{},
-		// 		},
-		// 	},
-		// 	wantChunk: nil,
-		// 	wantErr:   false,
-		// 	minRepo:   3,
-		// 	minOrg:    1,
-		// },
-		// {
-		// 	name: "unauthenticated, single repo",
-		// 	init: init{
-		// 		name: "test source",
-		// 		connection: &sourcespb.GitHub{
-		// 			Repositories: []string{"https://github.com/trufflesecurity/driftwood.git"},
-		// 			Credential:   &sourcespb.GitHub_Unauthenticated{},
-		// 		},
-		// 	},
-		// 	wantChunk: &sources.Chunk{
-		// 		SourceType: sourcespb.SourceType_SOURCE_TYPE_GITHUB,
-		// 		SourceName: "test source",
-		// 		SourceMetadata: &source_metadatapb.MetaData{
-		// 			Data: &source_metadatapb.MetaData_Github{
-		// 				Github: &source_metadatapb.Github{
-		// 					Repository: "https://github.com/trufflesecurity/driftwood.git",
-		// 				},
-		// 			},
-		// 		},
-		// 		Verify: false,
-		// 	},
-		// 	wantErr: false,
-		// },
+			wantErr: false,
+		},
 		{
 			name: "app authenticated, no repo or org",
 			init: init{
@@ -531,7 +474,7 @@ func TestSource_Scan(t *testing.T) {
 			},
 			wantChunk: nil,
 			wantErr:   false,
-			minRepo:   1,
+			minRepo:   32,
 			minOrg:    0,
 		},
 		{
@@ -623,19 +566,6 @@ func TestSource_paginateGists(t *testing.T) {
 	ctx, cancel := context.WithTimeout(context.Background(), time.Second*30)
 	defer cancel()
 
-	secret, err := common.GetTestSecret(ctx)
-	if err != nil {
-		t.Fatal(fmt.Errorf("failed to access secret: %v", err))
-	}
-	// For the  NEW github app test (+Member enum)
-	githubPrivateKeyB64New := secret.MustGetField("GITHUB_PRIVATE_KEY_NEW")
-	githubPrivateKeyBytesNew, err := base64.StdEncoding.DecodeString(githubPrivateKeyB64New)
-	if err != nil {
-		t.Fatal(err)
-	}
-	githubPrivateKeyNew := string(githubPrivateKeyBytesNew)
-	githubInstallationIDNew := secret.MustGetField("GITHUB_INSTALLATION_ID_NEW")
-	githubAppIDNew := secret.MustGetField("GITHUB_APP_ID_NEW")
 	type init struct {
 		name       string
 		verify     bool
@@ -654,13 +584,7 @@ func TestSource_paginateGists(t *testing.T) {
 			init: init{
 				name: "test source",
 				connection: &sourcespb.GitHub{
-					Credential: &sourcespb.GitHub_GithubApp{
-						GithubApp: &credentialspb.GitHubApp{
-							PrivateKey:     githubPrivateKeyNew,
-							InstallationId: githubInstallationIDNew,
-							AppId:          githubAppIDNew,
-						},
-					},
+					Credential: &sourcespb.GitHub_Unauthenticated{},
 				},
 			},
 			wantChunk: &sources.Chunk{
@@ -678,54 +602,19 @@ func TestSource_paginateGists(t *testing.T) {
 			user:     "truffle-sandbox",
 			minRepos: 1,
 		},
-		// {
-		// 	name: "get multiple pages of gists",
-		// 	init: init{
-		// 		name: "test source",
-		// 		connection: &sourcespb.GitHub{
-		// 			Credential: &sourcespb.GitHub_GithubApp{
-		// 				GithubApp: &credentialspb.GitHubApp{
-		// 					PrivateKey:     githubPrivateKeyNew,
-		// 					InstallationId: githubInstallationIDNew,
-		// 					AppId:          githubAppIDNew,
-		// 				},
-		// 			},
-		// 		},
-		// 	},
-		// 	wantChunk: nil,
-		// 	wantErr:   false,
-		// 	user:      "andrew",
-		// 	minRepos:  101,
-		// },
-		/*		{
-					name: "get multiple pages of gists",
-					init: init{
-						name: "test source",
-						connection: &sourcespb.GitHub{
-							Credential: &sourcespb.GitHub_GithubApp{
-								GithubApp: &credentialspb.GitHubApp{
-									PrivateKey:     githubPrivateKeyNew,
-									InstallationId: githubInstallationIDNew,
-									AppId:          githubAppIDNew,
-								},
-							},
-						},
-					},
-					wantChunk: &sources.Chunk{
-						SourceName: "test source",
-						SourceMetadata: &source_metadatapb.MetaData{
-							Data: &source_metadatapb.MetaData_Github{
-								Github: &source_metadatapb.Github{
-									Repository: "https://gist.github.com/872df3b78b9ec3e7dbe597fb5a202121.git",
-								},
-							},
-						},
-						Verify: false,
-					},
-					wantErr: false,
-					user:    "andrew",
+		{
+			name: "get multiple pages of gists",
+			init: init{
+				name: "test source",
+				connection: &sourcespb.GitHub{
+					Credential: &sourcespb.GitHub_Unauthenticated{},
 				},
-		*/
+			},
+			wantChunk: nil,
+			wantErr:   false,
+			user:      "andrew",
+			minRepos:  101,
+		},
 	}
 
 	for _, tt := range tests {
@@ -744,7 +633,7 @@ func TestSource_paginateGists(t *testing.T) {
 			}
 			chunksCh := make(chan *sources.Chunk, 5)
 			go func() {
-				s.addUserGistsToCache(ctx, tt.user)
+				assert.NoError(t, s.addUserGistsToCache(ctx, tt.user))
 				chunksCh <- &sources.Chunk{}
 			}()
 			var wantedRepo string
@@ -810,35 +699,6 @@ func githubCommentCheckFunc(gotChunk, wantChunk *sources.Chunk, i int, t *testin
 	}
 }
 
-// func TestSource_paginateRepos(t *testing.T) {
-// 	type args struct {
-// 		ctx       context.Context
-// 		apiClient *github.Client
-// 	}
-// 	tests := []struct {
-// 		name string
-// 		org  string
-// 		args args
-// 	}{
-// 		{
-// 			org: "fakeNetflix",
-// 			args: args{
-// 				ctx:       context.Background(),
-// 				apiClient: github.NewClient(common.SaneHttpClient()),
-// 			},
-// 		},
-// 	}
-// 	for _, tt := range tests {
-// 		t.Run(tt.name, func(t *testing.T) {
-// 			s := &Source{httpClient: common.SaneHttpClient()}
-// 			s.paginateRepos(tt.args.ctx, tt.args.apiClient, tt.org)
-// 			if len(s.repos) < 101 {
-// 				t.Errorf("expected > 100 repos, got %d", len(s.repos))
-// 			}
-// 		})
-// 	}
-// }
-
 func TestSource_Chunks_TargetedScan(t *testing.T) {
 	ctx, cancel := context.WithTimeout(context.Background(), time.Second*3000)
 	defer cancel()
@@ -870,10 +730,10 @@ func TestSource_Chunks_TargetedScan(t *testing.T) {
 				queryCriteria: &source_metadatapb.MetaData{
 					Data: &source_metadatapb.MetaData_Github{
 						Github: &source_metadatapb.Github{
-							Repository: "test_keys",
-							Link:       "https://github.com/trufflesecurity/test_keys/blob/fbc14303ffbf8fb1c2c1914e8dda7d0121633aca/keys#L4",
-							Commit:     "fbc14303ffbf8fb1c2c1914e8dda7d0121633aca",
-							File:       "keys",
+							Repository: "test-secrets",
+							Link:       "https://github.com/truffle-sandbox/test-secrets/blob/0416560b1330d8ac42045813251d85c688717eaf/new_key#L2",
+							Commit:     "0416560b1330d8ac42045813251d85c688717eaf",
+							File:       "new_key",
 						},
 					},
 				},
@@ -884,7 +744,7 @@ func TestSource_Chunks_TargetedScan(t *testing.T) {
 			name: "targeted scan, one file in med commit",
 			init: init{
 				name:       "test source",
-				connection: &sourcespb.GitHub{Credential: &sourcespb.GitHub_Token{Token: githubToken}},
+				connection: &sourcespb.GitHub{Credential: &sourcespb.GitHub_Unauthenticated{}},
 				queryCriteria: &source_metadatapb.MetaData{
 					Data: &source_metadatapb.MetaData_Github{
 						Github: &source_metadatapb.Github{
@@ -902,7 +762,7 @@ func TestSource_Chunks_TargetedScan(t *testing.T) {
 			name: "no file in commit",
 			init: init{
 				name:       "test source",
-				connection: &sourcespb.GitHub{Credential: &sourcespb.GitHub_Token{Token: githubToken}},
+				connection: &sourcespb.GitHub{Credential: &sourcespb.GitHub_Unauthenticated{}},
 				queryCriteria: &source_metadatapb.MetaData{
 					Data: &source_metadatapb.MetaData_Github{
 						Github: &source_metadatapb.Github{
@@ -921,7 +781,7 @@ func TestSource_Chunks_TargetedScan(t *testing.T) {
 			name: "invalid query criteria, malformed link",
 			init: init{
 				name:       "test source",
-				connection: &sourcespb.GitHub{Credential: &sourcespb.GitHub_Token{Token: githubToken}},
+				connection: &sourcespb.GitHub{Credential: &sourcespb.GitHub_Unauthenticated{}},
 				queryCriteria: &source_metadatapb.MetaData{
 					Data: &source_metadatapb.MetaData_Github{
 						Github: &source_metadatapb.Github{
