@@ -5,7 +5,6 @@ import (
 	"fmt"
 	"io"
 	"net/http"
-	"strconv"
 	"strings"
 	"sync"
 
@@ -15,8 +14,6 @@ import (
 	"github.com/trufflesecurity/trufflehog/v3/pkg/context"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/giturl"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/source_metadatapb"
-	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/sourcespb"
-	"github.com/trufflesecurity/trufflehog/v3/pkg/sources/git"
 )
 
 type repoInfoCache struct {
@@ -53,107 +50,8 @@ type repoInfo struct {
 	visibility source_metadatapb.Visibility
 }
 
-func (s *Source) cloneRepo(
-	ctx context.Context,
-	repoURL string,
-	installationClient *github.Client,
-) (string, *gogit.Repository, error) {
-	var (
-		path string
-		repo *gogit.Repository
-		err  error
-	)
-
-	switch s.conn.GetCredential().(type) {
-	case *sourcespb.GitHub_BasicAuth:
-		path, repo, err = git.CloneRepoUsingToken(ctx, s.conn.GetBasicAuth().GetPassword(), repoURL, s.conn.GetBasicAuth().GetUsername())
-		if err != nil {
-			return "", nil, err
-		}
-	case *sourcespb.GitHub_Unauthenticated:
-		path, repo, err = git.CloneRepoUsingUnauthenticated(ctx, repoURL)
-		if err != nil {
-			return "", nil, err
-		}
-
-	case *sourcespb.GitHub_GithubApp:
-		s.githubUser, s.githubToken, err = s.userAndToken(ctx, installationClient)
-		if err != nil {
-			return "", nil, fmt.Errorf("error getting token for repo %s: %w", repoURL, err)
-		}
-
-		path, repo, err = git.CloneRepoUsingToken(ctx, s.githubToken, repoURL, s.githubUser)
-		if err != nil {
-			return "", nil, err
-		}
-
-	case *sourcespb.GitHub_Token:
-		if err := s.getUserAndToken(ctx, repoURL, installationClient); err != nil {
-			return "", nil, fmt.Errorf("error getting token for repo %s: %w", repoURL, err)
-		}
-		path, repo, err = git.CloneRepoUsingToken(ctx, s.githubToken, repoURL, s.githubUser)
-		if err != nil {
-			return "", nil, err
-		}
-	default:
-		return "", nil, fmt.Errorf("unhandled credential type for repo %s: %T", repoURL, s.conn.GetCredential())
-	}
-	return path, repo, nil
-}
-
-func (s *Source) getUserAndToken(ctx context.Context, repoURL string, installationClient *github.Client) error {
-	// We never refresh user provided tokens, so if we already have them, we never need to try and fetch them again.
-	s.userMu.Lock()
-	defer s.userMu.Unlock()
-	if s.githubUser == "" || s.githubToken == "" {
-		var err error
-		s.githubUser, s.githubToken, err = s.userAndToken(ctx, installationClient)
-		if err != nil {
-			return fmt.Errorf("error getting token for repo %s: %w", repoURL, err)
-		}
-	}
-	return nil
-}
-
-func (s *Source) userAndToken(ctx context.Context, installationClient *github.Client) (string, string, error) {
-	switch cred := s.conn.GetCredential().(type) {
-	case *sourcespb.GitHub_BasicAuth:
-		return cred.BasicAuth.Username, cred.BasicAuth.Password, nil
-	case *sourcespb.GitHub_Unauthenticated:
-		// do nothing
-	case *sourcespb.GitHub_GithubApp:
-		id, err := strconv.ParseInt(cred.GithubApp.InstallationId, 10, 64)
-		if err != nil {
-			return "", "", fmt.Errorf("unable to parse installation id: %w", err)
-		}
-		// TODO: Check rate limit for this call.
-		token, _, err := installationClient.Apps.CreateInstallationToken(
-			ctx, id, &github.InstallationTokenOptions{})
-		if err != nil {
-			return "", "", fmt.Errorf("unable to create installation token: %w", err)
-		}
-		return "x-access-token", token.GetToken(), nil // TODO: multiple workers request this, track the TTL
-	case *sourcespb.GitHub_Token:
-		var (
-			ghUser *github.User
-			err    error
-		)
-		for {
-			ghUser, _, err = s.apiClient.Users.Get(ctx, "")
-			if s.handleRateLimit(err) {
-				continue
-			}
-			if err != nil {
-				return "", "", fmt.Errorf("unable to get user: %w", err)
-			}
-			break
-		}
-		return ghUser.GetLogin(), cred.Token, nil
-	default:
-		return "", "", fmt.Errorf("unhandled credential type")
-	}
-
-	return "", "", fmt.Errorf("unhandled credential type")
+func (s *Source) cloneRepo(ctx context.Context, repoURL string) (string, *gogit.Repository, error) {
+	return s.connector.Clone(ctx, repoURL)
 }
 
 type repoListOptions interface {
@@ -171,7 +69,7 @@ func (a *appListOptions) getListOptions() *github.ListOptions {
 }
 
 func (s *Source) appListReposWrapper(ctx context.Context, _ string, opts repoListOptions) ([]*github.Repository, *github.Response, error) {
-	someRepos, res, err := s.apiClient.Apps.ListRepos(ctx, opts.getListOptions())
+	someRepos, res, err := s.connector.APIClient().Apps.ListRepos(ctx, opts.getListOptions())
 	if someRepos != nil {
 		return someRepos.Repositories, res, err
 	}
@@ -195,7 +93,7 @@ func (u *userListOptions) getListOptions() *github.ListOptions {
 }
 
 func (s *Source) userListReposWrapper(ctx context.Context, user string, opts repoListOptions) ([]*github.Repository, *github.Response, error) {
-	return s.apiClient.Repositories.ListByUser(ctx, user, &opts.(*userListOptions).RepositoryListByUserOptions)
+	return s.connector.APIClient().Repositories.ListByUser(ctx, user, &opts.(*userListOptions).RepositoryListByUserOptions)
 }
 
 func (s *Source) getReposByUser(ctx context.Context, user string) error {
@@ -217,7 +115,8 @@ func (o *orgListOptions) getListOptions() *github.ListOptions {
 }
 
 func (s *Source) orgListReposWrapper(ctx context.Context, org string, opts repoListOptions) ([]*github.Repository, *github.Response, error) {
-	return s.apiClient.Repositories.ListByOrg(ctx, org, &opts.(*orgListOptions).RepositoryListByOrgOptions)
+	// TODO: It's possible to exclude forks when making the API request rather than doing post-request filtering
+	return s.connector.APIClient().Repositories.ListByOrg(ctx, org, &opts.(*orgListOptions).RepositoryListByOrgOptions)
 }
 
 func (s *Source) getReposByOrg(ctx context.Context, org string) error {
@@ -371,7 +270,7 @@ func (s *Source) wikiIsReachable(ctx context.Context, repoURL string) bool {
 		return false
 	}
 
-	res, err := s.httpClient.Do(req)
+	res, err := s.connector.APIClient().Client().Do(req)
 	if err != nil {
 		return false
 	}
@@ -398,7 +297,7 @@ func (s *Source) getDiffForFileInCommit(ctx context.Context, query commitQuery)
 		err    error
 	)
 	for {
-		commit, _, err = s.apiClient.Repositories.GetCommit(ctx, query.owner, query.repo, query.sha, nil)
+		commit, _, err = s.connector.APIClient().Repositories.GetCommit(ctx, query.owner, query.repo, query.sha, nil)
 		if s.handleRateLimit(err) {
 			continue
 		}
